/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity;

import java.io.IOException;

import org.databene.commons.IOUtil;
import org.databene.commons.xml.XMLUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Provides the DbSanity version number.<br/><br/>
 * Created: 13.10.2010 12:54:44
 * @since 1.0
 * @author Volker Bergmann
 */
public class Version {

	private static final Logger LOGGER = LoggerFactory.getLogger(Version.class);
	
	private static final String VERSION_FILE_URI = "org/databene/dbsanity/version.txt";
	
	public static final String VERSION = readVersion();

	public static void main(String[] args) {
		System.out.println(VERSION);
	}

	private static String readVersion() {
        String version = "<unknown version>";
	    try {
	        if (IOUtil.isURIAvailable(VERSION_FILE_URI))
	        	version = IOUtil.getContentOfURI(VERSION_FILE_URI);                         // This works in Maven, but...
	        if (version.startsWith("${") || version.startsWith("<unknown")) {               // ...in Eclipse no filtering is applied,...
	        	LOGGER.warn("Version number file could not be found, falling back to POM"); // ...so we fetch it directly from the POM!
	    		Document doc = XMLUtil.parse("pom.xml");
	    		Element versionElement = XMLUtil.getChildElement(doc.getDocumentElement(), false, true, "version");
	    		version = versionElement.getTextContent();
	        }
        } catch (IOException e) {
	        LOGGER.error("Error reading version info file", e);
        }
		return version;
    }
	
}
