package org.databene.dbsanity.db;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * Represents an abstract database object container with concrete instances for schemas, packages and tables.
 * @since 1.0
 * @author Björn Kellermann
 */
public abstract class AbstractDbPackage {
	
	protected String name;
	
	protected Map<String, DbTable> tables;
	protected Map<String, AbstractDbPackage> packages;
	
	public AbstractDbPackage(String name) {
		super();
		this.name = name;
		init();
	}
	
	public String getName() {
		return name;
	}
	
	public void register(DbTable table) {
		tables.put(table.getName(), table);
	}
	
	public void register(AbstractDbPackage dbPackage) {
		packages.put(dbPackage.getName(), dbPackage);
	}
	
	public Collection<DbTable> getTables() {
		return tables.values();
	}
	
	public Collection<AbstractDbPackage> getPackages() {
		return packages.values();
	}
	
	// protected
	
	protected void init() {
		tables = new HashMap<String, DbTable>();
		packages = new HashMap<String, AbstractDbPackage>();
	}
}
