package org.databene.dbsanity.db;

import java.sql.Connection;
import java.util.HashSet;
import java.util.Set;

import org.databene.dbsanity.model.SanityCheck;

/**
 * DbTable represents a database table related to a database schema (DbSchema).
 * DbTable(s) are grouped by their parent DbPackage.
 * @since 1.0
 * @author Björn Kellermann
 */
public class DbTable {
	
	protected String name;
	protected AbstractDbPackage dbPackage;
	protected DbSchema schema;
	
	protected Long amountOfData;
	
	protected Set<SanityCheck> checks;

	public DbTable(String name, AbstractDbPackage dbPackage, DbSchema schema) {
		super();
		this.name = name;
		this.dbPackage = dbPackage;
		this.schema = schema;
		init();	
	}
	
	public String getName() {
		return name;
	}
	
	public void reset() {
		checks = new HashSet<SanityCheck>();
		amountOfData = null;
	}

	public long getAmountOfData() {
		// lazy and only once, prevent calling again before reset()
		if (amountOfData == null) {
			String query = "Select count(*) from " + name;
			Connection con = schema.getConnection();
			// TODO v0.x execute query on connection -> count data
			// TODO v0.x assign result (count) to variable amountOfData
			amountOfData = new Long(0);
		}
		return amountOfData.longValue();
	}
	
	public void register(SanityCheck check) {
		checks.add(check);
	}
	
	// private helpers
	private void init() {
		reset();
	}

}
