package org.databene.dbsanity.model;

import java.io.File;
import java.sql.Connection;
import java.util.Date;

import org.databene.commons.Named;
import org.databene.dbsanity.Reporter;
import org.databene.dbsanity.report.ReportContext;

/**
 * Parent class for composite sanity checks. 
 * It provides methods to execute the sub checks and query their results.
 * @since 1.0
 * @author Yibo Wang
 * @author Volker Bergmann
 */
public abstract class SanityCheckSuite implements Named {
	
	protected SanityCheckFolder parent;
	protected String name;
	protected String ignorableTables;
	protected File reportFolder;

	public SanityCheckSuite(String name, File reportFolder, SanityCheckFolder parent) {
	    this.name = name;
	    this.reportFolder = reportFolder;
		this.parent = parent;
    }

	public String getName() {
		return name;
	}

	public SanityCheckFolder getParent() {
		return parent;
	}

	public SanityCheckSuite getRootSuite() {
		SanityCheckSuite result = this;
		while (result.getParent() != null)
			result = result.getParent();
		return result;
	}

	public String getIgnorableTables() {
		return (ignorableTables != null ? ignorableTables : (parent != null ? parent.getIgnorableTables() : null));
	}

	public void setIgnorableTables(String ignorableTables) {
		this.ignorableTables = ignorableTables;
	}
	
	public File getReportFolder() {
    	return reportFolder;
    }

	public SanityCheckVerdict getVerdict() {
		if (getErrorCount() > 0)
			return SanityCheckVerdict.ERROR;
		else if (getFailureCount() > 0)
			return SanityCheckVerdict.FAILED;
		else if (getSkipCount() > 0)
			return SanityCheckVerdict.SKIPPED;
		else if (getSuccessCount() > 0)
			return SanityCheckVerdict.PASSED;
		else
			return SanityCheckVerdict.PENDING;
	}

	public abstract void perform(Connection connection, Reporter reporter, ReportContext context);

	public abstract int getSkipCount();
	
	public abstract int getSuccessCount();
	
	public abstract int getFailureCount();
	
	public abstract int getErrorCount();
	
	public abstract int getDefectCount();
	
	public abstract Date getStartDate();
	
	public abstract int getExecutionTime();

}
