/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.parser;

import org.databene.commons.ConfigurationError;
import org.databene.commons.StringUtil;
import org.databene.commons.xml.XMLUtil;
import org.databene.dbsanity.model.SanityCheck;
import org.databene.dbsanity.model.SanityCheckFile;
import org.databene.dbsanity.model.db.DbsTable;
import org.databene.dbsanity.model.query.DefectQueryCheck;
import org.w3c.dom.Element;

/**
 * Parses a &lt;check&gt; element.<br/><br/>
 * Created: 05.12.2010 14:20:22
 * @since 0.4
 * @author Volker Bergmann
 */
public class CheckParser extends DbSanityXMLParser {

	public CheckParser() {
		super("check");
	}

	@Override
	public boolean supports(Element element, Object[] parentPath) {
		String name = element.getNodeName();
		if (!"check".equals(name) && !"test".equals(name))
			return false;
		Object parent = parent(parentPath);
		return (parent instanceof SanityCheckFile || parent instanceof DbsTable);
	}
	
	@Override
	public SanityCheck parse(Element testElement, Object[] parentPath, DbSanityParseContext context) {
	    Element sqlElement = XMLUtil.getChildElement(testElement, false, true, "sql");
	    Element queryElement = XMLUtil.getChildElement(sqlElement, false, false, "stmt");
	    if (queryElement == null)
	    	queryElement = sqlElement;
	    SanityCheckFile parentSanityCheckFile = ParseUtil.getParentSanityCheckFile(parentPath);
	    DefectQueryCheck check = new DefectQueryCheck(
	    		XMLUtil.getAttribute(testElement, "name", true),
	    		StringUtil.removeEmptyLines(XMLUtil.getWholeText(queryElement)),
	    		XMLUtil.getAttribute(testElement, "table", true),
	    		XMLUtil.getAttribute(testElement, "defectType", true),
	    		parentSanityCheckFile.getSourceFile(),
	    		parentSanityCheckFile.getTempFolder(),
	    		parentSanityCheckFile.getReportFolder(), 
	    		parentSanityCheckFile.getDocPage());
	    Element descElement = XMLUtil.getChildElement(testElement, false, false, "description");
	    if (descElement != null) {
		    String description = descElement.getTextContent();
		    check.setDescription(description);
	    }
	    context.checkUniqueness(check.getName());
	    String author = getOptionalAttribute("author", testElement);
	    if (author != null)
	    	check.setAuthor(author);
	    Object parent = parent(parentPath);
	    if (parent instanceof DbsTable)
	    	check.setTable(((DbsTable) parent).getName());
	    // if the test definition is a SQLUnit file, require it to expect an empty result set
	    Element resultElement = XMLUtil.getChildElement(testElement, false, false, "result");
	    if (resultElement != null) {
	    	Element resultSetElement = XMLUtil.getChildElement(resultElement, false, false, "resultset");
	    	if (resultSetElement != null)
	    		if (!"0".equals(resultSetElement.getAttribute("rowcount")))
	    			throw new ConfigurationError("DbSanity supports only SQLUnit test which expect an empty result set");
	    }
	    parentSanityCheckFile.addCheck(check);
	    return check;
	}

}
