/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.parser;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import org.databene.commons.ConfigurationError;
import org.databene.jdbacl.identity.IdentityProvider;
import org.databene.jdbacl.identity.KeyMapper;
import org.databene.jdbacl.model.Database;
import org.databene.webdecs.xml.ParseContext;
import org.databene.webdecs.xml.XMLElementParserFactory;

/**
 * {@link ParseContext} for DB Sanity.<br/><br/>
 * Created: 05.12.2010 12:47:26
 * @since 0.4
 * @author Volker Bergmann
 */
public class DbSanityParseContext extends ParseContext<Object> {
	
	protected IdentityProvider identityProvider;
	protected Database database;
	private Set<String> checks = new HashSet<String>();
	
	protected DbSanityParseContext parentContext;
	File sourceFile;
	File tempFolder;
	File reportFolder;
	private KeyMapper keyMapper;

	public DbSanityParseContext(File reportFolder, File tempFolder, IdentityProvider identityProvider, Database database, KeyMapper keyMapper) {
		super(Object.class, new XMLElementParserFactory<Object>());
		this.parentContext = null;
		this.sourceFile = null;
		this.reportFolder = reportFolder;
		this.tempFolder = tempFolder;
		this.identityProvider = identityProvider;
		this.database = database;
		this.keyMapper = keyMapper;
		// create parsers
		createParsers();
	}

	private DbSanityParseContext(DbSanityParseContext parentContext, File sourceFile, File reportFolder, File tempFolder) {
		super(Object.class, new XMLElementParserFactory<Object>());
		this.sourceFile = sourceFile;
		this.parentContext = parentContext;
		this.reportFolder = reportFolder;
		this.tempFolder = tempFolder;
		// create parsers
		createParsers();
	}
	
	public DbSanityParseContext createSubContext(File sourceFile, File reportFolder, File tempFolder) {
		return new DbSanityParseContext(this, sourceFile, reportFolder, tempFolder);
	}

	private void createParsers() {
		addParser(new DbSanityParser());
		// TODO v0.7 addParser(new PackageParser());
		// TODO v0.7 addParser(new TableParser());
		addParser(new IdentityParser());
		addParser(new CheckParser());
	}

	public File getSourceFile() {
		return sourceFile;
	}
	
	public File getReportFolder() {
		return reportFolder;
	}
	
	public File getTempFolder() {
		return tempFolder;
	}

	public IdentityProvider getIdentityProvider() {
		if (parentContext != null)
			return parentContext.getIdentityProvider();
		else
			return identityProvider;
	}

	public Database getDatabase() {
		if (parentContext != null)
			return parentContext.getDatabase();
		else
			return database;
	}
	
	public KeyMapper getKeyMapper() {
		if (parentContext != null)
			return parentContext.getKeyMapper();
		else
			return keyMapper;
	}

	public void checkUniqueness(String checkName) {
		if (parentContext != null)
			parentContext.checkUniqueness(checkName);
		else {
			if (checks.contains(checkName))
				throw new ConfigurationError("Duplicate test name: " + checkName);
			checks.add(checkName);
		}
    }

}
