/*
 * (c) Copyright 2010 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License (GPL).
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.dbsanity.report;

import org.databene.commons.file.FilePrintStream;
import org.databene.dbsanity.model.SanityCheckSuite;
import static org.databene.dbsanity.report.ReportUtil.*;

/**
 * Creates a summary HTML page for a folder with sanity check files and sub folders.<br/>
 * <br/>
 * Created: 26.10.2010 12:20:25
 * @since 1.0
 * @author Volker Bergmann
 */
public abstract class VerdictSummaryModule extends AbstractReportModule {

	@Override
	public int getDashboardColSpan(ReportScope scope) {
		return 1;
	}
	
	public void statsTable(SanityCheckSuite suite, FilePrintStream out) {
	    out.println("				<table cellpadding='3' cellspacing='0'>");
	    out.println("					<tr class='defect' style='font-size:20'>" +
	    		"<td align='right'><b>" + context.formatLong(suite.getDefectCount(), "No") + "</b></td>" +
	    		"<td align='left'>Defects</td>" +
	    		"<td align='right'>&nbsp;</td></tr>");
	    out.println("					<tr><td colspan='3'>&nbsp;</td></tr>");
	    out.println("					<tr><td colspan='3'><b>Checks:</b></td></tr>");
	    out.println("					<tr style='color:#000000'>" +
	    	"<td align='right'>" + context.formatLong(suite.getErrorCount(), "No")   + "</td>" +
	    	"<td align='left'>faulty</td>" +
	    	"<td align='right'>("    + context.formatDecimal(getErrorPercentage(suite))   + "%)</td></tr>");
	    out.println("					<tr style='color:#" + ReportContext.RED + "'>" +
	    	"<td align='right'>" + context.formatLong(suite.getFailureCount(), "No") + "</td>" +
	    	"<td align='left'>violated</td>" +
	    	"<td align='right'>("  + context.formatDecimal(getFailurePercentage(suite)) + "%)</td></tr>");
	    out.println("					<tr style='color:#" + ReportContext.GREEN + "'>" +
	    	"<td align='right'>" + context.formatLong(suite.getSuccessCount(), "No") + "</td>" +
	    	"<td align='left'>passed</td>" +
	    	"<td align='right'>(" + context.formatDecimal(getSuccessPercentage(suite)) + "%)</td></tr>");
	    double skipPercentage = getSkipPercentage(suite);
	    if (skipPercentage > 0) {
		    out.println("					<tr style='color:#B0B0B0'>" +
		    	"<td align='right'>" + context.formatLong(suite.getSkipCount(), "No") + "</td>" +
		    	"<td align='left'>skipped</td>" +
		    	"<td align='right'>(" + context.formatDecimal(skipPercentage) + "%)</td></tr>");
	    }
		out.println("				</table>");
    }

}
